pub async fn insert_many(
conn: &mut PgConnection,
exercise_task_submission_id: Uuid,
file_upload_ids: &[Uuid],
) -> ModelResult<()>Expand description
Records the files a task submission was made from, in the order the client sent them.
pub async fn insert_many(
conn: &mut PgConnection,
exercise_task_submission_id: Uuid,
file_upload_ids: &[Uuid],
) -> ModelResult<()>Records the files a task submission was made from, in the order the client sent them.